@@ -1,6 +1,6 @@
 --- a/include/autoconf.hin
 +++ b/include/autoconf.hin
-@@ -1003,4 +1003,8 @@ Added missing headers after gettext upda
+@@ -1017,6 +1017,10 @@ Added missing headers after gettext upda
   */
  #	undef USE_ZLIB
  
@@ -8,4 +8,6 @@
 +#define XFACE_ABLE
 +#define NNTP_SERVER_FILE "/etc/news/server"
 +
- #endif /* !TIN_AUTOCONF_H */
+ /*
+  * signal-types
+  */
